@@ -61,7 +61,7 @@
 //!
 //! ## Supported Languages
 //!
-//! ### Permissively Licensed (100 languages, included by default)
+//! ### Permissively Licensed (97 languages, included by default)
 //!
 //! | Language | Feature Flag | License |
 //! |----------|--------------|---------|
@@ -88,16 +88,10 @@
 
 //! | Cap&#039;n Proto | `lang-capnp` | MIT |
 
-//! | Cedar | `lang-cedar` | MIT OR Apache-2.0 |
-
-//! | Cedar Schema | `lang-cedarschema` | MIT OR Apache-2.0 |
-
 //! | Clojure | `lang-clojure` | Unlicense |
 
 //! | CMake | `lang-cmake` | MIT |
 
-//! | COBOL | `lang-cobol` | MIT |
-
 //! | Common Lisp | `lang-commonlisp` | MIT |
 
 //! | C++ | `lang-cpp` | MIT |
@@ -162,6 +156,8 @@
 
 //! | Julia | `lang-julia` | MIT |
 
+//! | KDL | `lang-kdl` | MIT OR Apache-2.0 |
+
 //! | Kotlin | `lang-kotlin` | MIT |
 
 //! | Lean | `lang-lean` | MIT |
@@ -212,8 +208,6 @@
 
 //! | SCSS | `lang-scss` | MIT |
 
-//! | Solidity | `lang-solidity` | MIT |
-
 //! | SPARQL | `lang-sparql` | MIT |
 
 //! | SQL | `lang-sql` | MIT |
@@ -417,12 +411,6 @@ pub fn detect_language(path: &str) -> Option<&'static str> {
 
         "capnp" => "capnp",
 
-        "cbl" => "cobol",
-
-        "cedar" => "cedar",
-
-        "cedarschema" => "cedarschema",
-
         "cfg" => "ini",
 
         "cjs" => "javascript",
@@ -437,18 +425,12 @@ pub fn detect_language(path: &str) -> Option<&'static str> {
 
         "cmd" => "batch",
 
-        "cob" => "cobol",
-
-        "cobol" => "cobol",
-
         "commonlisp" => "commonlisp",
 
         "conf" => "ini",
 
         "cpp" => "cpp",
 
-        "cpy" => "cobol",
-
         "cs" => "c-sharp",
 
         "csharp" => "c-sharp",
@@ -569,6 +551,8 @@ pub fn detect_language(path: &str) -> Option<&'static str> {
 
         "julia" => "julia",
 
+        "kdl" => "kdl",
+
         "kotlin" => "kotlin",
 
         "kt" => "kotlin",
@@ -693,10 +677,6 @@ pub fn detect_language(path: &str) -> Option<&'static str> {
 
         "shell" => "bash",
 
-        "sol" => "solidity",
-
-        "solidity" => "solidity",
-
         "sparql" => "sparql",
 
         "sql" => "sql",
@@ -855,14 +835,6 @@ pub use arborium_caddy as lang_caddy;
 pub use arborium_capnp as lang_capnp;
 
 
-#[cfg(feature = "lang-cedar")]
-pub use arborium_cedar as lang_cedar;
-
-
-#[cfg(feature = "lang-cedarschema")]
-pub use arborium_cedarschema as lang_cedarschema;
-
-
 #[cfg(feature = "lang-clojure")]
 pub use arborium_clojure as lang_clojure;
 
@@ -871,10 +843,6 @@ pub use arborium_clojure as lang_clojure;
 pub use arborium_cmake as lang_cmake;
 
 
-#[cfg(feature = "lang-cobol")]
-pub use arborium_cobol as lang_cobol;
-
-
 #[cfg(feature = "lang-commonlisp")]
 pub use arborium_commonlisp as lang_commonlisp;
 
@@ -1003,6 +971,10 @@ pub use arborium_json as lang_json;
 pub use arborium_julia as lang_julia;
 
 
+#[cfg(feature = "lang-kdl")]
+pub use arborium_kdl as lang_kdl;
+
+
 #[cfg(feature = "lang-kotlin")]
 pub use arborium_kotlin as lang_kotlin;
 
@@ -1107,10 +1079,6 @@ pub use arborium_scheme as lang_scheme;
 pub use arborium_scss as lang_scss;
 
 
-#[cfg(feature = "lang-solidity")]
-pub use arborium_solidity as lang_solidity;
-
-
 #[cfg(feature = "lang-sparql")]
 pub use arborium_sparql as lang_sparql;
 
