@@ -14,6 +14,7 @@ pub enum AVAILABLE_LOCALES {
     PT_PT,
     DE_DE,
     IT_IT,
+    CY_GB,
 }
 
 macro_rules! fake_gen_on_return_type {
@@ -69,6 +70,10 @@ macro_rules! some_rules {
                 let s = faker::$module::it_it::$fake($($arg)?);
                 Box::new(move |rng: &mut R| fake_gen_on_return_type!(s,rng$(,$return_type)?))
             }
+            AVAILABLE_LOCALES::CY_GB => {
+                let s = faker::$module::cy_gb::$fake($($arg)?);
+                Box::new(move |rng: &mut R| fake_gen_on_return_type!(s,rng$(,$return_type)?))
+            }
         }
     };
 }
@@ -201,6 +206,16 @@ pub fn all_fakegen_commands<R: Rng>() -> (
         (Paragraph(min:usize=5, max:usize=10),lorem),
         (Paragraphs(min:usize=5, max:usize=10)->Vec,lorem),
 
+        //markdown
+        (ItalicWord,markdown),
+        (BoldWord,markdown),
+        (Link,markdown),
+        (BulletPoints(min:usize=5, max:usize=10)->Vec,markdown),
+        (ListItems(min:usize=5, max:usize=10)->Vec,markdown),
+        (BlockQuoteSingleLine(min:usize=5, max:usize=10),markdown),
+        (BlockQuoteMultiLine(min:usize=5, max:usize=10)->Vec,markdown),
+        (Code(min:usize=5, max:usize=10),markdown),
+
         //name
         (FirstName,name),
         (LastName,name),
