@@ -300,7 +300,7 @@ impl Builder {
 ///
 /// [Service Account Key]: https://cloud.google.com/iam/docs/keys-create-delete#creating
 #[derive(serde::Deserialize, Default, Clone)]
-struct ServiceAccountKey {
+pub(crate) struct ServiceAccountKey {
     /// The client email address of the service account.
     /// (e.g., "my-sa@my-project.iam.gserviceaccount.com").
     client_email: String,
@@ -377,7 +377,7 @@ impl TokenProvider for ServiceAccountTokenProvider {
 }
 
 #[derive(Default, Clone)]
-struct ServiceAccountTokenGenerator {
+pub(crate) struct ServiceAccountTokenGenerator {
     service_account_key: ServiceAccountKey,
     audience: Option<String>,
     scopes: Option<String>,
@@ -385,7 +385,21 @@ struct ServiceAccountTokenGenerator {
 }
 
 impl ServiceAccountTokenGenerator {
-    fn generate(&self) -> Result<String> {
+    #[cfg(google_cloud_unstable_id_token)]
+    pub(crate) fn new_id_token_generator(
+        target_audience: String,
+        audience: String,
+        service_account_key: ServiceAccountKey,
+    ) -> Self {
+        Self {
+            service_account_key,
+            target_audience: Some(target_audience),
+            audience: Some(audience),
+            scopes: None,
+        }
+    }
+
+    pub(crate) fn generate(&self) -> Result<String> {
         let signer = self.signer(&self.service_account_key.private_key)?;
 
         // The claims encode a unix timestamp. `std::time::Instant` has no
@@ -464,156 +478,6 @@ where
     }
 }
 
-#[cfg(google_cloud_unstable_id_token)]
-pub mod idtoken {
-    use crate::Result;
-    use crate::build_errors::Error as BuilderError;
-    use crate::constants::{JWT_BEARER_GRANT_TYPE, OAUTH2_TOKEN_SERVER_URL};
-    use crate::credentials::CacheableResource;
-    use crate::credentials::idtoken::dynamic::IDTokenCredentialsProvider;
-    use crate::credentials::service_account::{ServiceAccountKey, ServiceAccountTokenGenerator};
-    use crate::token::{CachedTokenProvider, Token, TokenProvider};
-    use crate::token_cache::TokenCache;
-    use crate::{BuildResult, credentials::idtoken::IDTokenCredentials};
-    use async_trait::async_trait;
-    use gax::error::CredentialsError;
-    use http::Extensions;
-    use reqwest::Client;
-    use serde_json::Value;
-    use std::sync::Arc;
-
-    #[derive(Debug)]
-    struct ServiceAccountCredentials<T>
-    where
-        T: CachedTokenProvider,
-    {
-        token_provider: T,
-    }
-
-    #[async_trait]
-    impl<T> IDTokenCredentialsProvider for ServiceAccountCredentials<T>
-    where
-        T: CachedTokenProvider,
-    {
-        async fn id_token(&self) -> Result<String> {
-            let cached_token = self.token_provider.token(Extensions::new()).await?;
-            match cached_token {
-                CacheableResource::New { data, .. } => Ok(data.token),
-                CacheableResource::NotModified => {
-                    Err(CredentialsError::from_msg(false, "failed to fetch token"))
-                }
-            }
-        }
-    }
-
-    #[derive(Debug)]
-    struct ServiceAccountTokenProvider {
-        service_account_key: ServiceAccountKey,
-        audience: String,
-        target_audience: String,
-        token_server_url: String,
-    }
-
-    #[async_trait]
-    impl TokenProvider for ServiceAccountTokenProvider {
-        async fn token(&self) -> Result<Token> {
-            let audience = self.audience.clone();
-            let target_audience = Some(self.target_audience.clone());
-            let service_account_key = self.service_account_key.clone();
-            let tg = ServiceAccountTokenGenerator {
-                audience: Some(audience),
-                service_account_key,
-                target_audience,
-                scopes: None,
-            };
-            let assertion = tg.generate()?;
-
-            let client = Client::new();
-            let request = client.post(&self.token_server_url).form(&[
-                ("grant_type", JWT_BEARER_GRANT_TYPE.to_string()),
-                ("assertion", assertion),
-            ]);
-
-            let response = request
-                .send()
-                .await
-                .map_err(|e| crate::errors::from_http_error(e, "failed to exchange id token"))?;
-
-            if !response.status().is_success() {
-                let err =
-                    crate::errors::from_http_response(response, "failed to fetch id token").await;
-                return Err(err);
-            }
-
-            let token = response
-                .text()
-                .await
-                .map_err(|e| CredentialsError::from_source(!e.is_decode(), e))?;
-
-            Ok(Token {
-                token,
-                token_type: "Bearer".to_string(),
-                expires_at: None,
-                metadata: None,
-            })
-        }
-    }
-
-    pub struct Builder {
-        service_account_key: Value,
-        target_audience: String,
-        token_server_url: String,
-    }
-
-    /// Creates [`IDTokenCredentials`] instances that fetch ID tokens using
-    /// service accounts.
-    impl Builder {
-        /// The `target_audience` is a required parameter that specifies the
-        /// intended audience of the ID token. This is typically the URL of the
-        /// service that will be receiving the token.
-        pub fn new<S: Into<String>>(target_audience: S, service_account_key: Value) -> Self {
-            Self {
-                service_account_key,
-                target_audience: target_audience.into(),
-                token_server_url: OAUTH2_TOKEN_SERVER_URL.to_string(),
-            }
-        }
-
-        #[cfg(test)]
-        pub(crate) fn with_token_server_url<S: Into<String>>(mut self, url: S) -> Self {
-            self.token_server_url = url.into();
-            self
-        }
-
-        fn build_token_provider(
-            self,
-            target_audience: String,
-        ) -> BuildResult<ServiceAccountTokenProvider> {
-            let service_account_key =
-                serde_json::from_value::<ServiceAccountKey>(self.service_account_key)
-                    .map_err(BuilderError::parsing)?;
-            Ok(ServiceAccountTokenProvider {
-                service_account_key,
-                audience: OAUTH2_TOKEN_SERVER_URL.to_string(),
-                target_audience,
-                token_server_url: self.token_server_url,
-            })
-        }
-
-        /// Returns an [`IDTokenCredentials`] instance with the configured
-        /// settings.
-        pub fn build(self) -> BuildResult<IDTokenCredentials> {
-            let target_audience = self.target_audience.clone();
-            let creds = ServiceAccountCredentials {
-                token_provider: TokenCache::new(self.build_token_provider(target_audience)?),
-            };
-            Ok(IDTokenCredentials {
-                inner: Arc::new(creds),
-            })
-        }
-    }
-}
-
 #[cfg(test)]
 mod tests {
     use super::*;
@@ -755,7 +619,7 @@ mod tests {
         assert!(sac.headers(Extensions::new()).await.is_err());
     }
 
-    pub(crate) fn get_mock_service_key() -> Value {
+    fn get_mock_service_key() -> Value {
         json!({
             "client_email": "test-client-email",
             "private_key_id": "test-private-key-id",
@@ -988,94 +852,3 @@ mod tests {
         Ok(())
     }
 }
-
-#[cfg(all(test, google_cloud_unstable_id_token))]
-mod unstable_tests {
-    use super::tests::*;
-    use super::*;
-    use crate::constants::JWT_BEARER_GRANT_TYPE;
-    use crate::credentials::tests::PKCS8_PK;
-    use httptest::{
-        Expectation, Server,
-        matchers::{all_of, any, contains, request, url_decoded},
-        responders::*,
-    };
-    use serde_json::Value;
-
-    type TestResult = std::result::Result<(), Box<dyn std::error::Error>>;
-
-    #[tokio::test]
-    async fn idtoken_success() -> TestResult {
-        let server = Server::run();
-        server.expect(
-            Expectation::matching(all_of![
-                request::method("POST"),
-                request::path("/"),
-                request::body(url_decoded(contains(("grant_type", JWT_BEARER_GRANT_TYPE)))),
-                request::body(url_decoded(contains(("assertion", any())))),
-            ])
-            .respond_with(status_code(200).body("test-id-token")),
-        );
-
-        let mut service_account_key = get_mock_service_key();
-        service_account_key["private_key"] = Value::from(PKCS8_PK.clone());
-
-        let creds = idtoken::Builder::new("test-audience", service_account_key)
-            .with_token_server_url(server.url("/").to_string())
-            .build()?;
-
-        let token = creds.id_token().await?;
-        assert_eq!(token, "test-id-token");
-        Ok(())
-    }
-
-    #[tokio::test]
-    async fn idtoken_http_error() -> TestResult {
-        let server = Server::run();
-        server.expect(
-            Expectation::matching(all_of![request::method("POST"), request::path("/"),])
-                .respond_with(status_code(501)),
-        );
-
-        let mut service_account_key = get_mock_service_key();
-        service_account_key["private_key"] = Value::from(PKCS8_PK.clone());
-
-        let creds = idtoken::Builder::new("test-audience", service_account_key)
-            .with_token_server_url(server.url("/").to_string())
-            .build()?;
-
-        let err = creds.id_token().await.unwrap_err();
-        assert!(!err.is_transient());
-        Ok(())
-    }
-
-    #[tokio::test]
-    async fn idtoken_caching() -> TestResult {
-        let server = Server::run();
-        server.expect(
-            Expectation::matching(all_of![
-                request::method("POST"),
-                request::path("/"),
-                request::body(url_decoded(contains(("grant_type", JWT_BEARER_GRANT_TYPE)))),
-                request::body(url_decoded(contains(("assertion", any())))),
-            ])
-            .times(1)
-            .respond_with(status_code(200).body("test-id-token")),
-        );
-
-        let mut service_account_key = get_mock_service_key();
-        service_account_key["private_key"] = Value::from(PKCS8_PK.clone());
-
-        let creds = idtoken::Builder::new("test-audience", service_account_key)
-            .with_token_server_url(format!("http://{}", server.addr()))
-            .build()?;
-
-        let id_token = creds.id_token().await?;
-        assert_eq!(id_token, "test-id-token");
-
-        let id_token = creds.id_token().await?;
-        assert_eq!(id_token, "test-id-token");
-
-        Ok(())
-    }
-}
