@@ -9,14 +9,13 @@
 use base64::Engine;
 use hyper::body::Bytes;
 use hyper::http::{HeaderMap, HeaderValue};
-use hyper_util::client::legacy::connect::HttpConnector;
 use hyper_util::client::legacy::Client;
+use hyper_util::client::legacy::connect::HttpConnector;
 use hyper_util::rt::TokioExecutor;
-use jsonrpsee_core::tracing::client::{rx_log_from_bytes, tx_log_from_str};
 use jsonrpsee_core::BoxError;
 use jsonrpsee_core::{
-	http_helpers::{self, HttpError},
 	TEN_MB_SIZE_BYTES,
+	http_helpers::{self, HttpError},
 };
 use std::future::Future;
 use std::pin::Pin;
@@ -93,16 +92,18 @@ pub struct HttpTransportClientBuilder<L> {
 	pub(crate) max_request_size: u32,
 	/// Configurable max response body size
 	pub(crate) max_response_size: u32,
-	/// Max length for logging for requests and responses
-	///
-	/// Logs bigger than this limit will be truncated.
-	pub(crate) max_log_length: u32,
 	/// Custom headers to pass with every request.
 	pub(crate) headers: HeaderMap,
 	/// Service builder
 	pub(crate) service_builder: tower::ServiceBuilder<L>,
 	/// TCP_NODELAY
 	pub(crate) tcp_no_delay: bool,
+	/// KEEP_ALIVE duration
+	pub(crate) keep_alive_duration: Option<std::time::Duration>,
+	/// KEEP_ALIVE interval
+	pub(crate) keep_alive_interval: Option<std::time::Duration>,
+	/// KEEP_ALIVE retries
+	pub(crate) keep_alive_retries: Option<u32>,
 }
 
 impl Default for HttpTransportClientBuilder<Identity> {
@@ -119,10 +120,12 @@ impl HttpTransportClientBuilder<Identity> {
 			certificate_store: CertificateStore::Native,
 			max_request_size: TEN_MB_SIZE_BYTES,
 			max_response_size: TEN_MB_SIZE_BYTES,
-			max_log_length: 1024,
 			headers: HeaderMap::new(),
 			service_builder: tower::ServiceBuilder::new(),
 			tcp_no_delay: true,
+			keep_alive_duration: None,
+			keep_alive_interval: None,
+			keep_alive_retries: None,
 		}
 	}
 }
@@ -163,11 +166,21 @@ impl<L> HttpTransportClientBuilder<L> {
 		self
 	}
 
-	/// Max length for logging for requests and responses in number characters.
-	///
-	/// Logs bigger than this limit will be truncated.
-	pub fn set_max_logging_length(mut self, max: u32) -> Self {
-		self.max_log_length = max;
+	/// Configure the keep-alive duration for the connection.
+	pub fn set_keep_alive(mut self, duration: Option<std::time::Duration>) -> Self {
+		self.keep_alive_duration = duration;
+		self
+	}
+
+	/// Configure the keep-alive interval for the connection.
+	pub fn set_keep_alive_interval(mut self, interval: Option<std::time::Duration>) -> Self {
+		self.keep_alive_interval = interval;
+		self
+	}
+
+	/// Configure the number of keep-alive retries for the connection.
+	pub fn set_keep_alive_retries(mut self, retries: Option<u32>) -> Self {
+		self.keep_alive_retries = retries;
 		self
 	}
 
@@ -177,11 +190,13 @@ impl<L> HttpTransportClientBuilder<L> {
 			#[cfg(feature = "tls")]
 			certificate_store: self.certificate_store,
 			headers: self.headers,
-			max_log_length: self.max_log_length,
 			max_request_size: self.max_request_size,
 			max_response_size: self.max_response_size,
 			service_builder: service,
 			tcp_no_delay: self.tcp_no_delay,
+			keep_alive_duration: self.keep_alive_duration,
+			keep_alive_retries: self.keep_alive_retries,
+			keep_alive_interval: self.keep_alive_interval,
 		}
 	}
 
@@ -199,10 +214,12 @@ impl<L> HttpTransportClientBuilder<L> {
 			certificate_store,
 			max_request_size,
 			max_response_size,
-			max_log_length,
 			headers,
 			service_builder,
 			tcp_no_delay,
+			keep_alive_duration,
+			keep_alive_interval,
+			keep_alive_retries,
 		} = self;
 		let mut url = Url::parse(target.as_ref()).map_err(|e| Error::Url(format!("Invalid URL: {e}")))?;
 
@@ -215,6 +232,9 @@ impl<L> HttpTransportClientBuilder<L> {
 			"http" => {
 				let mut connector = HttpConnector::new();
 				connector.set_nodelay(tcp_no_delay);
+				connector.set_keepalive(keep_alive_duration);
+				connector.set_keepalive_interval(keep_alive_interval);
+				connector.set_keepalive_retries(keep_alive_retries);
 				HttpBackend::Http(Client::builder(TokioExecutor::new()).build(connector))
 			}
 			#[cfg(feature = "tls")]
@@ -228,6 +248,9 @@ impl<L> HttpTransportClientBuilder<L> {
 				let mut http_conn = HttpConnector::new();
 				http_conn.set_nodelay(tcp_no_delay);
 				http_conn.enforce_http(false);
+				http_conn.set_keepalive(keep_alive_duration);
+				http_conn.set_keepalive_interval(keep_alive_interval);
+				http_conn.set_keepalive_retries(keep_alive_retries);
 
 				let https_conn = match certificate_store {
 					CertificateStore::Native => {
@@ -280,13 +303,14 @@ impl<L> HttpTransportClientBuilder<L> {
 				);
 			}
 		}
+		let _ = url.set_password(None);
+		let _ = url.set_username("");
 
 		Ok(HttpTransportClient {
 			target: url.as_str().to_owned(),
 			client: service_builder.service(client),
 			max_request_size,
 			max_response_size,
-			max_log_length,
 			headers: cached_headers,
 		})
 	}
@@ -303,10 +327,6 @@ pub struct HttpTransportClient<S> {
 	max_request_size: u32,
 	/// Configurable max response body size
 	max_response_size: u32,
-	/// Max length for logging for requests and responses
-	///
-	/// Logs bigger than this limit will be truncated.
-	max_log_length: u32,
 	/// Custom headers to pass with every request.
 	headers: HeaderMap,
 }
@@ -340,22 +360,17 @@ where
 
 	/// Send serialized message and wait until all bytes from the HTTP message body have been read.
 	pub(crate) async fn send_and_read_body(&self, body: String) -> Result<Vec<u8>, Error> {
-		tx_log_from_str(&body, self.max_log_length);
-
 		let response = self.inner_send(body).await?;
+
 		let (parts, body) = response.into_parts();
-
 		let (body, _is_single) = http_helpers::read_body(&parts.headers, body, self.max_response_size).await?;
 
-		rx_log_from_bytes(&body, self.max_log_length);
-
 		Ok(body)
 	}
 
 	/// Send serialized message without reading the HTTP message body.
 	pub(crate) async fn send(&self, body: String) -> Result<(), Error> {
-		let _ = self.inner_send(body).await?;
-
+		self.inner_send(body).await?;
 		Ok(())
 	}
 }
