@@ -13,7 +13,7 @@ use syn::{parse_quote, Attribute, Expr, FnArg, Ident, ItemFn, Pat, Path, ReturnT
 use quote::{format_ident, quote};
 
 use crate::refident::MaybePat;
-use crate::utils::{attr_ends_with, sanitize_ident};
+use crate::utils::sanitize_ident;
 use crate::{
     parse::{
         rstest::{RsTestAttributes, RsTestInfo},
@@ -29,7 +29,7 @@ use crate::{
 use wrapper::WrapByModule;
 
 pub(crate) use fixture::render as fixture;
-
+use crate::parse::arguments::TestAttr;
 use self::apply_arguments::ApplyArguments;
 use self::crate_resolver::crate_name;
 pub(crate) mod apply_arguments;
@@ -208,11 +208,20 @@ pub(crate) fn matrix(mut test: ItemFn, mut info: RsTestInfo) -> TokenStream {
     test_group(test, rendered_cases)
 }
 
-fn resolve_default_test_attr(is_async: bool) -> TokenStream {
-    if is_async {
-        quote! { #[async_std::test] }
-    } else {
-        quote! { #[test] }
+fn resolve_test_attr(
+    test_attr: Option<&TestAttr>,
+) -> Option<TokenStream> {
+    match test_attr {
+        Some(TestAttr::Explicit(attr)) => {
+            Some(quote! { #attr })
+        }
+        Some(TestAttr::InAttrs) => {
+            // test attr is already in the attributes; we don't need to re-inject it
+            None
+        }
+        None => {
+            Some(quote! { #[test] })
+        }
     }
 }
 
@@ -347,15 +356,7 @@ fn single_test_case(
         .last()
         .map(|attribute| attribute.parse_args::<Expr>().unwrap());
 
-    // If no injected attribute provided use the default one
-    let test_attr = if attrs
-        .iter()
-        .any(|a| attr_ends_with(a, &parse_quote! {test}))
-    {
-        None
-    } else {
-        Some(resolve_default_test_attr(is_async))
-    };
+    let test_attr = resolve_test_attr(info.arguments.test_attr());
 
     let args = args
         .iter()
@@ -371,12 +372,18 @@ fn single_test_case(
         .collect::<Vec<_>>();
 
     let execute = render_test_call(testfn_name.clone().into(), &args, timeout, is_async);
-    let lifetimes = generics.lifetimes();
-
+    let mut lifetimes = generics.lifetimes().peekable();
+    let lifetimes = if lifetimes.peek().is_some() {
+        Some(quote! {<#(#lifetimes,)*>})
+    } else {
+       None 
+    };
+    
+    
     quote! {
         #(#attrs)*
         #test_attr
-        #asyncness fn #name<#(#lifetimes,)*>(#(#ignored_args,)*) #output {
+        #asyncness fn #name #lifetimes (#(#ignored_args,)*) #output {
             #test_impl
             #inject
             #trace_args
