@@ -25,7 +25,7 @@ impl<'a> WindowsComponent<'a> {
     /// Returns path representing this specific component
     pub fn as_path<T>(&self) -> &Path<T>
     where
-        T: for<'enc> Encoding<'enc>,
+        T: Encoding,
     {
         Path::new(self.as_bytes())
     }
@@ -249,7 +249,7 @@ impl AsRef<[u8]> for WindowsComponent<'_> {
 
 impl<T> AsRef<Path<T>> for WindowsComponent<'_>
 where
-    T: for<'enc> Encoding<'enc>,
+    T: Encoding,
 {
     #[inline]
     fn as_ref(&self) -> &Path<T> {
@@ -431,7 +431,7 @@ mod tests {
 
     use super::*;
 
-    fn make_windows_prefix_component(s: &str) -> WindowsComponent {
+    fn make_windows_prefix_component(s: &str) -> WindowsComponent<'_> {
         let component = WindowsComponent::try_from(s).unwrap();
         assert!(component.is_prefix());
         component
@@ -498,7 +498,7 @@ mod tests {
 
         use crate::windows::WindowsPrefix;
 
-        fn make_component(s: &str) -> Component {
+        fn make_component(s: &str) -> Component<'_> {
             let component = Path::new(s).components().next();
             assert!(
                 matches!(component, Some(Component::Prefix(_))),
